
// ImageViewer.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, May 2022

// Used as a canvas to display tiling


import java.awt.*;
import javax.swing.*;
import java.awt.image.*;
import java.awt.event.*;
import java.awt.geom.*;
import java.util.*;


public class ImageViewer extends JPanel 
             implements MouseListener, MouseMotionListener

{ 
  private int pWidth, pHeight;
  private BufferedImage scrIm;

  private Popup coordsPopup;  // used to display mouse coordinates over the pane


  public ImageViewer(int pWidth, int pHeight)
  {
    this.pWidth = pWidth;
    this.pHeight = pHeight;

    scrIm = new BufferedImage(pWidth, pHeight, 
                   BufferedImage.TYPE_INT_ARGB); // alpha channel

    setPreferredSize( new Dimension(pWidth, pHeight));

    addMouseListener(this);
    addMouseMotionListener(this);
  }  // end of ImageViewer()


  public BufferedImage getImage()
  {  return scrIm;  }

  public int getWidth()
  {  return scrIm.getWidth();  }

  public int getHeight()
  {  return scrIm.getHeight();  }

  public Graphics2D createGraphics()
  {  return Pics.createGraphics(scrIm);  }


  public void paintComponent(Graphics g)
  {
    super.paintComponent(g);
    Graphics2D g2d = (Graphics2D)g; 

    // use antialiasing
    g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
                          RenderingHints.VALUE_ANTIALIAS_ON);

    g2d.setRenderingHint(RenderingHints.KEY_RENDERING,
                           RenderingHints.VALUE_RENDER_QUALITY);

    g2d.drawImage(scrIm, 0, 0, null);
  } // end of paintComponent()


//  public void repaint()
//  {   super.repaint();  }



  public void update(BufferedImage im)
  {
    if ((im.getWidth() != scrIm.getWidth()) ||
        (im.getHeight() != scrIm.getHeight()) ) 
      System.out.println("Warning updated viewer image is a different size");

    scrIm = im;
    repaint();
  }


  public boolean outsidePane(Tile t)
  // a tile is outside only if ALL of its points are outside
  {  
    ArrayList<Point2D.Double> pts = t.getPtLocs();
    for (Point2D.Double pt : pts)
      if (!outsidePane(pt))
        return false;    
    return true;
  }



  public boolean outsidePane(Point2D.Double pt)
  {  return outsidePane(pt.x, pt.y);  }


  public boolean outsidePane(double xPt, double yPt)
  {
    int x = (int)Math.round(xPt);
    int y = (int)Math.round(yPt);
    return ((x < 0) || (x > scrIm.getWidth()) || 
            (y < 0) || (y > scrIm.getHeight()));
  }


  // ------- MouseListener methods --------

  public void mousePressed( MouseEvent e)
  // display the mouse coordinates in a popup window
  { 
    JLabel text = new JLabel("(" + 
          e.getX() + "," + e.getY() + ")");
    coordsPopup = PopupFactory.getSharedInstance().
                  getPopup(e.getComponent(), text, 
                     e.getXOnScreen()+15, e.getYOnScreen());
    coordsPopup.show();
  }

  public void mouseReleased( MouseEvent e)
  { 
    if (coordsPopup != null)
      coordsPopup.hide();
  }

  public void mouseClicked(MouseEvent e) {}
  public void mouseEntered(MouseEvent e) {}
  public void mouseExited(MouseEvent e) {}


  // ------- MouseMotionListener methods --------

  public void mouseDragged( MouseEvent e)
  // display the mouse coordinates in a moving popup window
  {
   if (coordsPopup != null)
     coordsPopup.hide();
   JLabel text = new JLabel("(" + 
         e.getX() + "," + e.getY() + ")");
   coordsPopup = PopupFactory.getSharedInstance().
                 getPopup(e.getComponent(), text, 
                    e.getXOnScreen()+15, e.getYOnScreen());
   coordsPopup.show();
  }

  public void mouseMoved(MouseEvent e) {}

 
}  // end of ImageViewer class