
// PicInfo.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Prints size and transparency info about an image file.
   Including "-v" adds a LOT of metadata in XML format.

   Usage:
     > java PicInfo data/dart.png
     > java PicInfo -v data/trif.png > info.txt
*/


import java.awt.image.*;


public class PicInfo 
{

  public static void main(String[] args)
  {
    if ((args.length < 1) || (args.length > 2)) {
      System.out.println("Usage: java PicsInfo [-v] <fnm>");
      return;
    }

    String fnm = null;
    boolean isVerbose = false;
    if (args.length == 2) {
      fnm = args[1];
      isVerbose = args[0].equals("-v");
    }
    else
      fnm = args[0];

    BufferedImage im = Pics.load(fnm);
    if (im == null) {
      System.out.println("Could not load an image from " + fnm);
      return;
    }
    System.out.println("Dimensions: (" + im.getWidth() + ", " +
                                         im.getHeight() + ")");
    Pics.colorModel(im);
    System.out.println("Has an alpha channel: " + Pics.hasAlpha(im));
    System.out.println("Contains transparent pixels: " + 
                                      Pics.containsTransparency(im));

    if (isVerbose)
      Pics.showMetadata(fnm);
  }  // end of main()


}  // end of PicInfo class


