
// PointPairs.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/*
*/

import java.awt.image.*;
import java.util.*;
import java.util.function.*;



public class PointPairs
{
  private static final double LENGTH_EPS = 1.0;  // in pixels

  private ArrayList<Pair<String,String>> ptPairs;


  public PointPairs()
  {
    ptPairs = new ArrayList<>();
  }


  public PointPairs(Tile[] ts)
  {
    ptPairs = new ArrayList<>();

    ArrayList<String> allPts = new ArrayList<>();
    for (Tile t : ts)
      allPts.addAll(t.getPtNames());

    String[] pts = allPts.toArray(new String[0]);
    System.out.println("Pair pts: " + Arrays.toString(pts));

    add(pts, pts); // all pts are the same
  }  



  public PointPairs(Tile t)
  {
    ptPairs = new ArrayList<>();
    ArrayList<String> ptNames = t.getPtNames();
    add(ptNames, ptNames); // all pts are the same
  }  



  public void add(String from, String to)
  {  ptPairs.add( new Pair<String,String>(from, to));  }


  public void add(String[] fromArr, String to)
  { for(int i=0; i < fromArr.length; i++)
      add(fromArr[i], to);
  }

  public void add(ArrayList<String> froms, String to)
  { for(String from : froms)
      add(from, to);
  }

  public void add(String from, String[] toArr)
  { for(int i=0; i < toArr.length; i++)
      add(from, toArr[i]);
  }

  public void add(String from, ArrayList<String> tos)
  { for(String to : tos)
      add(from, to);
  }

  public void add(String[] fromArr, String[] toArr)
  { for(int i=0; i < fromArr.length; i++)
      add(fromArr[i], toArr);
  }

  public void add(ArrayList<String> froms, ArrayList<String> tos)
  { for(String from : froms)
      add(from, tos);
  }



  public ArrayList<String> fromMatches(String fromName)
  // get all the 'to' names that match this 'from' name
  {
    ArrayList<String> matches = new ArrayList<>();
    for(Pair<String,String> pair : ptPairs) {
      if (fromName.equals(pair.getX()))
        matches.add( pair.getY());
    }
    return matches;
  }  // end of fromMatches()


  public ArrayList<String> toMatches(String toName)
  // get all the 'from' names that match this 'to' name
  {
    ArrayList<String> matches = new ArrayList<>();
    for(Pair<String,String> pair : ptPairs) {
      if (toName.equals(pair.getY()))
        matches.add( pair.getX());
    }
    return matches;
  }  // end of toMatches()



  public boolean isMatch(String fromPt, String toPt)
  {  return (matchIdx(fromPt, toPt) != -1);  }


  public int matchIdx(String fromPt, String toPt)
  {
    for(int i=0; i < ptPairs.size(); i++) {
      Pair<String,String> pair = ptPairs.get(i);
      if (fromPt.equals(pair.getX()) && toPt.equals(pair.getY()))
        return i;
    }
    return -1;
  }  // end of matchIdx()



  public boolean delete(String fromPt, String toPt)
  {
    int idx = matchIdx(fromPt, toPt);
    if (idx == -1) {
      System.out.println("Could not delete " + fromPt + "->" + toPt);
      return false;
    }
    else {
      ptPairs.remove(idx);
      System.out.println("Deleted " + fromPt + "->" + toPt);
      return true;
    }
  }  // end of delete()



  public void deleteFroms(String fromPt)
  // delete all the pairs that use fromPt
  {
    int idx = 0;
    int count = 0;
    while (idx < ptPairs.size()) {
      Pair<String,String> pair = ptPairs.get(idx);
      if (fromPt.equals(pair.getX())) {
        ptPairs.remove(idx);
        count++;
      }
      else
        idx++;
    }
    System.out.println("Removed " + count + " pairs for " + fromPt);
  }  // end of deleteFroms()



  public void deleteTos(String toPt)
  // delete all the pairs that use toPt
  {
    int idx = 0;
    int count = 0;
    while (idx < ptPairs.size()) {
      Pair<String,String> pair = ptPairs.get(idx);
      if (toPt.equals(pair.getY())) {
        ptPairs.remove(idx);
        count++;
      }
      else
        idx++;
    }
    System.out.println("Removed " + count + " pairs for " + toPt);
  }  // end of deleteTos()



  public void print()
  {
    System.out.println("Point Pairs:");
    int colCnt = 0;
    for(Pair<String,String> pair : ptPairs) {
      System.out.print(" " + pair.getX() +
                      "->" + pair.getY() + ";");
      colCnt++;
      if (colCnt%9 == 0)
        System.out.println();
    }
    System.out.println("\n---");
  }  // end of print()


  // --------------- static methods -----------------


  public static PointPairs matchLens(Tile t)
  {  return matchLens(new Tile[]{t} );  }


  public static PointPairs matchLens(Tile[] ts)
  // match all points that have the same side lengths
  {
    PointPairs pp = new PointPairs();
    System.out.println("Point Pairs based on side lengths:");
    for (Tile t : ts) {
      for (int i=0; i < t.numPts(); i++) {
        String ptName = t.ptName(i);
        double len = t.length(ptName, t.nextName(ptName));  // ccw order
        String[] toNms = matchLen(len, ts);
        pp.add(ptName, toNms);
        System.out.println("  Added: " + ptName + " -> " + Arrays.toString(toNms));
      }
    }
    return pp;
  }  // end of matchLens()



  private static String[] matchLen(double len, Tile[] ts)
  // collect all the 'to' pts that have side lengths == len
  {
    ArrayList<String> toNms = new ArrayList<String>();
    for (Tile t : ts) {
      for (int i=0; i < t.numPts(); i++) {
        String ptName = t.ptName(i);
        double toLen = t.length(t.prevName(ptName), ptName);  // cw order
        if (Math.abs(len - toLen) <= LENGTH_EPS)
          toNms.add(ptName);
      }
    }
    return toNms.toArray(new String[0]);
  }  // end of matchLen()


}  // end of PointPairs