
// Polar.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Polar coordinates 
*/

import java.awt.*;
import java.awt.geom.*;


public class Polar
{
  private double theta;    // in degrees between 0 and 360
  private double radius;


  public Polar(double theta, double radius)
  {
    this.theta = restrictAngle(theta);
    this.radius = radius;
  }

  public double getAngle()
  {  return theta;  } 

  public double getRadius()
  {  return radius;  }


  public Point2D.Double getCartesian()
  {
    double rad = Math.toRadians(theta);
  	double x = Math.cos(rad)*radius;
  	double y = Math.sin(rad)*radius;
    return new Point2D.Double(x, y);
  }

  public Polar rotate(double angle)   // rotate ccw
  {  return new Polar( restrictAngle(theta + angle), radius);  }


  private double restrictAngle(double d)
  // d must range between 0 and 360
  {
    if (d > 360) {
      while (d > 360)
        d =  d - 360;
    }

    if (d < 0) {
      while (d < 0)
        d = d + 360;
    }
    return d;
  }  // end of restrictAngle()



  public Polar resize(double factor)
  {
    if (factor <= 0) {
      System.out.println("Resize factor must be positive");
      return new Polar(theta, radius);
    }
    else
      return new Polar(theta, radius*factor);
  }



  public Polar flip(int flipType)
  {
    double nTheta  = theta;
    if (flipType == Pics.VERT) {  // vertical axis
      if (theta <= 180)   // first & 2nd quadrants
        nTheta = 180 - theta;
      else // 3rd and 4th quadrants
        nTheta = 360 - (theta - 180);
    }
    else if (flipType == Pics.HORIZ) {  // horizontal axis
      nTheta = 360 - theta;
    }
    else if (flipType == Pics.BOTH) {   // same as 180 rotation
      return rotate(180);
    }
    else 
      System.out.println("Unknown flip type: " + flipType);

    return new Polar(nTheta, radius);
  }  // end of flip()



  public String toString()
  {  return String.format("(theta: %.2f, r: %.2f)", theta, radius);  }



  // ------------ test rig -----------

  public static void main(String args[])
  {
    Polar p = new Polar(30, 100);
    System.out.println("p = " + p);
    System.out.println("  coord: " + p.getCartesian());
    
    Polar p1 = p.rotate(90);
    System.out.println("\nRotated p 90 = " + p1);
    System.out.println("  " + p1.getCartesian());

    Polar p2 = p.resize(2);
    System.out.println("\nResized p *2 = " + p2);
    System.out.println("  " + p2.getCartesian());

    Polar p3 = p.flip(Pics.HORIZ);
    System.out.println("\nFlipped p horiz = " + p3);
    System.out.println("  " + p3.getCartesian());

    p3 = p3.flip(Pics.VERT);
    System.out.println("\nThen Flipped vert = " + p3);
    System.out.println("  " + p3.getCartesian());

  } // end of main()


} // end of Polar