
// Spotty.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, May 2022

/* Press the mouse button to draw and record an inner point.
   Type 'u' to undo drawn points.
   Inner and outer point code is printed on closing.
*/


import java.awt.*;
import javax.swing.*;
import java.awt.image.*;
import java.awt.event.*;
import java.util.*;


public class Spotty extends JPanel 
             implements KeyListener, MouseListener
{ 
  private int pWidth, pHeight;
  private BufferedImage im;

  private ArrayList<Point> pts = new ArrayList<>();


  public Spotty(BufferedImage im)
  {
    this.im = im;

    pWidth = im.getWidth();
    pHeight = im.getHeight();
    setPreferredSize( new Dimension(pWidth, pHeight));

    addMouseListener(this);
    addKeyListener(this);
    setFocusable(true);
  }  // end of Spotty()


  public void printPoints()
  // manual copy and paste the printed lines
  {  
    if (pts.isEmpty())
      System.out.println("No points recorded");
    else {
       System.out.println("double[] xs = new double[] { ");
       System.out.print("    ");
       for (int i=0; i < pts.size()-1; i++) {
          System.out.printf("%3d, ", pts.get(i).x);
          if ((i+1)%8 == 0)
            System.out.print("\n    ");
       }
       System.out.printf("%3d };\n", pts.get(pts.size()-1).x);

       System.out.println("double[] ys = new double[] { ");
       System.out.print("    ");
       for (int i=0; i < pts.size()-1; i++) {
          System.out.printf("%3d, ", pts.get(i).y);
          if ((i+1)%8 == 0)
            System.out.print("\n    ");
       }
       System.out.printf("%3d };\n", pts.get(pts.size()-1).y);
    }
  }  // end of printPoints()


  public void paintComponent(Graphics g)
  {
    super.paintComponent(g);
    Graphics2D g2d = (Graphics2D)g; 

    g2d.drawImage(im, 0, 0, null);

    g2d.setColor(Color.BLUE);
    for (Point pt : pts)
      g2d.fillOval(pt.x-3, pt.y-3, 6, 6);

  } // end of paintComponent()


  // ------- MouseListener methods --------


    public void mousePressed(MouseEvent e)
    { 
      int x = e.getX();
      int y = e.getY();
      System.out.println("(" + x + ", " + y + ")");
      pts.add( new Point(x,y));
      repaint();
    }

    public void mouseClicked(MouseEvent e) {}
    public void mouseReleased(MouseEvent e) {}
    public void mouseEntered(MouseEvent e) {}
    public void mouseExited(MouseEvent e) {}


  // ------- KeyListener methods --------

    public void keyTyped(KeyEvent e) 
    {
      // System.out.println("Typed " + e.getKeyChar());
      if (e.getKeyChar() == 'u') {
        if (!pts.isEmpty()) {
          pts.remove( pts.size()-1);
          repaint();
        }
      }
    }
 
    public void keyPressed(KeyEvent e) {}
    public void keyReleased(KeyEvent e) {}

  // ------------------------------------------


  public static void main(String args[])
  {
    if (args.length != 1) {
      System.out.println("Usage: java Spotty <fnm>");
      System.out.println("  Press the mouse button to draw and record a point.");
      System.out.println("  Type 'u' to undo drawn points.");
      System.out.println("  Suitable inner point code is printed on closing.");
      return;
    }

    Tile t = new Tile(args[0]);
    BufferedImage im = t.getImage();
    // BufferedImage im = Pics.load(args[0]);
    if (im == null) {
      System.out.println("Unrecognized file type");
      return;
    }

    Spotty pane = new Spotty(im);

    JFrame f = new JFrame("Generate Inner Points");
    f.getContentPane().add(pane, BorderLayout.CENTER);

    f.addWindowListener( new WindowAdapter() {
      public void windowClosing(WindowEvent e) 
      { pane.printPoints();
        System.exit(0);
      }
    });
    // f.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

    f.pack();
    f.setResizable(false);  
    f.setVisible(true);
  } // end of main()

}  // end of Spotty class