
// ViewTile.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* A standalone program for viewing a tile, including its
   image points and automatically generated inner and outer points
   (as green and blue dots).

   A tile can be loaded from an image file, a Tile text file, or an SVG file.

   Note that an image file has no image points, and so it's not possible
   to generate inner and outer points for it. Also, most SVG files have
   too many points, which are automatically deleted at load time. This
   means that the loaded SVG will not have inner or outer points either.

   When ViewTile closes, the image is automatically stored in TileViewer.png.
   This can be loaded into a graphics program (e.g. MS Paint)
   so the pixel position of points can be more easily
   checked.

   It is also possible to click on the loaded image to see a popup
   window containing the cursor's current position inside the image.


  Examples:
     > java ViewTile data/axe1.png
     > java ViewTile data/pentagon.png

     > java ViewTile data/starTile.txt
     > java ViewTile data/yTile.txt
     > java ViewTile data/tiles1.txt
     > java ViewTile data/dartTile.txt
     > java ViewTile data/kiteTile.txt
     > java ViewTile data/nutTile.txt
     > java ViewTile data/arrowTile.txt

     > java ViewTile data/axe2.svg  
     > java ViewTile data/lizard.svg 
*/

import java.awt.*;
import java.io.*;


public class ViewTile
{

  public static void main(String[] args)
  {
    if (args.length != 1) {
      System.out.println("Usage: java ViewTile <txt fnm>");
      return;
    }

    Tile t = new Tile(args[0]);
    if (t == null)
      return;

    if (t.numPts() > Tile.MAX_SVG_POINTS)
      t.clearPts();

    t.genInners();   // generates default values (when there are points)
    t.genOuters();

    t.view();
    t.reportPoints();
  }  // end of main()

}  // end of ViewTile class