
// Arrows.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Uses Search.tileLocs() for tiling. Compare with DrawArrows.java
   which uses row-by-row tiling.
*/

import java.awt.*;
import java.awt.image.*;
import java.util.*;
import java.util.function.*;
import java.awt.geom.*;



public class Arrows
{
  private static final Color[] colors = { 
       new Color(199,255,244), new Color(255, 210, 199),
       new Color(255, 238, 119), new Color(221, 199, 255)
  };   // https://www.sessions.edu/color-calculator/

  private static Random rand = new Random();

  private static Tile arrow;


  public static void main(String args[])
  {
    // only one tile required
    arrow = new Tile("data/arrowTile.txt"); 
    Graphics2D g2d = arrow.getGraphics();
    // red circle
    g2d.setColor(Color.RED);
    g2d.fillOval(55, 78, 10, 10);  // near to the arrow tip

    /* ViewTile shows that the default outer points 
        are poorly positioned, so define our own */

    arrow.addOuter("A0", "A1", 62, 39);
    arrow.addOuter("A1", "A2", 63, 115);
    arrow.addOuter("A2", "A3", 106, 125);
    arrow.addOuter("A3", "A4", 144, 118);
    arrow.addOuter("A4", "A5", 198, 92);
    arrow.addOuter("A5", "A6", 197, 63);
    arrow.addOuter("A6", "A7", 140, 39);
    arrow.addOuter("A7", "A0", 106, 32);

    arrow.view();
    arrow.reportPoints();

    // PointPairs ptPairs = PointPairs.matchLens(arrow);
      /* Does not work due to concave sides (and too general).
         It generates:
           A0 -> [A1, A2]      // too general
           A1 -> [A1, A2]
           A2 -> [A0, A3, A5, A6]
           A3 -> [A4, A7]
           A4 -> [A0, A3, A5, A6]
           A5 -> [A0, A3, A5, A6]
           A6 -> [A4, A7]
           A7 -> [A0, A3, A5, A6]
      */

    PointPairs ptPairs = new PointPairs();
    // sqrt(2) sides
    ptPairs.add("A0", "A1");
    ptPairs.add("A1", "A2");
    // 1.5 sides
    ptPairs.add("A3", "A4");
    ptPairs.add("A6", "A7");
    // 0.5 sides
    ptPairs.add("A2", "A5");
    ptPairs.add("A4", "A3");
    ptPairs.add("A5", "A0");
    ptPairs.add("A7", "A6");

    ptPairs.print();

    Function<String, Tile> genTile = 
       (String nm)->{ return arrow.colorChg(
                       colors[rand.nextInt(colors.length)]); };
          // randomly colored arrows

    // draw tiles on the screen
    ImageViewer iview = Pics.view("Draw Arrows", Pics.altScreen());
    Search.tileLocs(arrow, ptPairs, iview, genTile);
    Pics.save(iview.getImage(), "SavedPics/arrows.png");
  } // end of main()



} // end of Arrows class
