
// Axes.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th


import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;



public class Axes
{

  public static void main(String args[])
  {
    // two tile approaches: SVG or PNG

    // generate two tiles 
    Tile longAxe = new Tile("data/axe2.svg");  // created in Inkscape
      // loads one path, and removes 70 SVG path points
    longAxe.addPt("A0", 24, 18);
    longAxe.addPt("A1", 24, 80);  // from MS paint on TileViewer.png
    longAxe.addPt("A2", 84, 80);  
    longAxe.addPt("A3", 84, 18);

    longAxe.view();
    longAxe.reportPoints();

    Tile tallAxe =  longAxe.rotate(90);
    tallAxe.view();
    tallAxe.reportPoints();


    ImageViewer iview = Pics.view("Axes", Pics.altScreen());
    BufferedImage scrIm = iview.getImage();
    int pWidth = scrIm.getWidth();
    int pHeight = scrIm.getHeight();


    // display tiles row-by-row
    int rowNum = 1;
    Point2D.Double startPt = new Point2D.Double(0,0);
    Point2D.Double nextPt;
    Tile t;

    while (startPt.y < pHeight) {
      // start of a row
      if (rowNum%2 == 1) {  // long axe first
        longAxe.drawAt(scrIm, "A0", startPt);
        startPt = longAxe.getPtLoc("A1");
        nextPt = longAxe.getPtLoc("A3");
      }
      else {  // tall axe first
        tallAxe.drawAt(scrIm, "A3", startPt);
        startPt = tallAxe.getPtLoc("A0");
        nextPt = tallAxe.getPtLoc("A2");
      }

      // rest of row  
      while (nextPt.x < pWidth) {
        if (rowNum%2 == 1) {  // tall, long
          tallAxe.drawAt(scrIm, "A3", nextPt);
          longAxe.drawAt(scrIm, "A0", 
                            tallAxe.getPtLoc("A2"));
          nextPt = longAxe.getPtLoc("A3");
        }
        else {   // long, tall
          longAxe.drawAt(scrIm, "A0", nextPt);
          tallAxe.drawAt(scrIm, "A3", 
                            longAxe.getPtLoc("A3"));
          nextPt = tallAxe.getPtLoc("A2");
        }
       iview.repaint();
      }
      Pics.pause(100);   // delay after each row is drawn
      rowNum++;
    }

    Pics.save(scrIm, "SavedPics/axes.png");
  }  // end of main()


} // end of Axes class
