
// DrawATriangle.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/*  Illustrates the difference between image coordinates and
    drawn coordinates for a tile.
*/

import java.awt.*;
import java.awt.image.*;
import java.awt.geom.*;



public class DrawATriangle
{

  public static void main(String args[])
  {
    // an equilateral triangle
    Shape s = ShapeOps.radPolygon(Tile.WIDTH/2, Tile.HEIGHT/2, 30, 3);  
                                 // center, radius, no. of sides
    s = ShapeOps.rotate(s, 90);  // rotate ccw so first point (T0) is the tip

    Tile tri = new Tile(s, "triangle");
       // the points will be labelled "T0", "T1", ...

    Graphics2D g2d = tri.getGraphics();
    g2d.setFont( new Font("Algerian", Font.PLAIN, 32));
    g2d.drawString("f", 48, 67);  // centered 'f' inside the triangle
      // I obtained these coords by looking at the Tile.view() output

    tri.view();
    tri.reportPoints();


    // draw the tile in a window of size 200 x 200 (width x height)
    ImageViewer iview = Pics.view("Draw a Triangle", 200, 200);

    // uncomment one of these lines...
    // beforeAfterDraw(tri, iview);
    drawTiles(tri, iview);

  }   // end of main()


  private static void beforeAfterDraw(Tile tri, ImageViewer iview)
  {
    System.out.println("Before drawing...");
    System.out.println("  Image Center: " + tri.getCenterIm());
    System.out.println("  Drawn Center: " + tri.getCenterLoc());   // will be null
    System.out.println("  Image Tip: " + tri.getPtIm("T0"));
    System.out.println("  Drawn Tip: " + tri.getPtLoc("T0"));    // will be null

    // 3 examples; choose one:
    // tri.draw(scrIm);   // draw triangle so is centered
    // tri.drawAt(scrIm, "T0");   // draw triangle so TO is centered
    tri.drawAt(iview.getImage(), "T0", 100, 50);   
               // draw triangle so TO is at (100,50)
    iview.repaint();

    System.out.println("\nAfter drawing...");
    System.out.println("  Image Center: " + tri.getCenterIm());  // unchanged
    System.out.println("  Drawn Center: " + tri.getCenterLoc());
    System.out.println("  Image Tip: " + tri.getPtIm("T0"));  // unchanged
    System.out.println("  Drawn Tip: " + tri.getPtLoc("T0"));

  }  // end of beforeAfterDraw()


  private static void drawTiles(Tile tri, ImageViewer iview)
  // display some tiles 
  {
    Tile rot = tri.rotate(180);
    rot.setID("rot");    // this does not change the point names
    rot.view();
    rot.reportPoints();

    BufferedImage scrIm = iview.getImage();

    tri.drawAt(scrIm, "T0", 30, 0);

/*
    // tile across
    Point2D.Double pt = tri.getPtLoc("T0");
    rot.drawAt(scrIm, "T2", pt);

    pt = rot.getPtLoc("T1");
    tri.drawAt(scrIm, "T0", pt);
    iview.repaint();
*/

    // tile down
    Point2D.Double pt = tri.getPtLoc("T1");
    rot.drawAt(scrIm, "T2", pt);
    iview.repaint();

  }  // end of drawTiles()


} // end of DrawATriangle class
