
// DrawArrows.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Uses row-by-row tiling. Compare with Arrows.java
   which uses Search.tileLocs() for tiling.
*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;


public class DrawArrows
{
  private static final Color[] colors = { 
       new Color(199,255,244), new Color(255, 210, 199),
       new Color(255, 238, 119), new Color(221, 199, 255)
  };   // https://www.sessions.edu/color-calculator/


  private static Random rand = new Random();


  public static void main(String args[])
  {
    // create left- and right- pointing arrow tiles
    Tile left = new Tile("data/arrowTile.txt");
    left.setID("left");
    Graphics2D g2d = left.getGraphics();
    // red circle
    g2d.setColor(Color.RED);
    g2d.fillOval(55, 78, 10, 10);  // near to the arrow tip

    left.view();
    left.reportPoints();

    Tile right = left.rotate(180);
    right.setID("right");
    right.view();
    right.reportPoints();

    ImageViewer iview = Pics.view("Draw Arrows", Pics.altScreen());
    BufferedImage scrIm = iview.getImage();
    int pWidth = scrIm.getWidth();
    int pHeight = scrIm.getHeight();


    // display tiles row-by-row
    int rowNum = 1;
    Point2D.Double startPt = new Point2D.Double(30,0);
    Point2D.Double nextPt;
    Tile t;

    while (startPt.y < pHeight) {
      // start of a row
      if (rowNum%2 == 1) {  // left arrow
        t = randColor(left);
        t.drawAt(scrIm, "A7", startPt);
        startPt = t.getPtLoc("A3");
        nextPt = t.getPtLoc("A5");
      }
      else {  // right arrow
        t = randColor(right);
        t.drawAt(scrIm, "A4", startPt);
        startPt = t.getPtLoc("A6");
        nextPt = t.getPtLoc("A1");
      }

      // rest of row  
      while (nextPt.x < pWidth) {
        if (rowNum%2 == 1) {  // left arrows
          t = randColor(left);
          t.drawAt(scrIm, "A1", nextPt);
          nextPt = t.getPtLoc("A5");
        }
        else {   // right arrows
          t = randColor(right);
          t.drawAt(scrIm, "A5", nextPt);
          nextPt = t.getPtLoc("A1");
        }
       iview.repaint();
      }
      Pics.pause(100);   // delay after each row is drawn
      rowNum++;
    }

    Pics.save(scrIm, "SavedPics/arrowsRow.png");
  } // end of main()


  private static Tile randColor(Tile t)
  {  return t.colorChg( colors[rand.nextInt(colors.length)]);  }


} // end of DrawArrows class
