
// DrawCTris.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Use of composition to create a tile from
   4 triangle tiles.

   This triangle image is also used in DrawTris.java and Triangles.java
*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;


public class DrawCTris
{
  private static final int TILE_WIDTH = 300;     
  private static final int TILE_HEIGHT = 300;


  public static void main(String args[])
  {
    Tile ct = makeComposite();

    ImageViewer iview = Pics.view("Using a Composite",  Pics.altScreen());
    BufferedImage scrIm = iview.getImage();
    int pWidth = scrIm.getWidth();
    int pHeight = scrIm.getHeight();

    // display tiles row-by-row
    Point2D.Double startPt = new Point2D.Double(30,0);
    Point2D.Double nextPt;

    while (startPt.y < pHeight) {
      // start of a row
      ct.drawAt(scrIm, "C0", startPt);
      startPt = ct.getPtLoc("C2");
      nextPt = ct.getPtLoc("C5");

      // rest of row  
      while (nextPt.x < pWidth) {
        ct.drawAt(scrIm, "C0", nextPt);
        nextPt = ct.getPtLoc("C5");
        iview.repaint();
      }
      Pics.pause(100);   // delay after each row is drawn
    }

    Pics.save(scrIm, "SavedPics/cTris.png");
  } // end of main()



  private static Tile makeComposite()
  {
    Tile t = new Tile("data/trif.png");
    t.addPt("T0", 51,6);   // added in ccw order
    t.addPt("T1", 4,86); 
    t.addPt("T2", 97,86);
    t.view();
    t.reportPoints();

    Tile rot = t.rotate(180);
    rot.setID("rot");    // this does not change the point names
    rot.view();
    rot.reportPoints();

    BufferedImage im = new BufferedImage(TILE_WIDTH, TILE_HEIGHT, 
                          BufferedImage.TYPE_INT_ARGB);  // alpha channel
    int xc = TILE_WIDTH/2;
    int yc = TILE_HEIGHT/2;

    Point2D.Double[] corners = new Point2D.Double[6];

    /* The composite is four triangles drawn around the center; 
       the corner points are also collected */
    t.drawAt(im, "T2", xc, yc);
    corners[0] = t.getPtLoc("T0"); 
    corners[1] = t.getPtLoc("T1"); 

    rot.drawAt(im, "T1", xc, yc);
    corners[2] = rot.getPtLoc("T0"); 

    t.drawAt(im, "T0", xc, yc);
    corners[3] = t.getPtLoc("T2"); 

    rot.drawAt(im, "T0", xc, yc);
    corners[4] = rot.getPtLoc("T0"); 
    corners[5] = rot.getPtLoc("T1"); 


    // create composite tile, and add its corners
    Tile ctTile = new Tile(im, "comp");
    for (int i=0; i < corners.length; i++)
      ctTile.addPt("C"+i, corners[i]);

    ctTile.view();
    ctTile.reportPoints();

    return ctTile;
  }   // end of makeComposite()


} // end of DrawCTris class
