
// DrawCurves.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* An SVG tile using curves. 
*/

import java.awt.*;
import java.awt.image.*;
import java.util.*;
import java.util.function.*;
import java.awt.geom.*;



public class DrawCurves
{
  private static final Color LIGHT_BLUE = Color.decode("#4287f5"); 
            // can be obtained from curves.svg's path.style.fill attribute

  private static Tile curvy;


  public static void main(String args[])
  {
    curvy = new Tile("data/curves.svg").colorChg(LIGHT_BLUE);
      // 6 paths are combined automatically,
      // and 2687 points are cleared
    curvy.addPt("A0", 14, 16);
    curvy.addPt("A1", 14, 98);  // obtained by viewing TileViewer.png in MS paint
    curvy.addPt("A2", 96, 98);  // only four points are needed 
    curvy.addPt("A3", 96, 16);

    Graphics2D g2d = curvy.getGraphics();
    // white circle at top-right
    g2d.setPaint(Color.WHITE);
    g2d.fillOval(70, 23, 10, 10);

    curvy.view();
    curvy.reportPoints();

    // default inner and outer points are good enough

    PointPairs ptPairs = new PointPairs(curvy);  // all points can match
    ptPairs.print();

    Function<String, Tile> genTile = 
                      (String nm)->{return curvy.clone();};

    // draw tiles on the screen
    ImageViewer iview = Pics.view("Draw curves", Pics.altScreen());

    // Search.tileSpacey(curvy, ptPairs, iview, genTile);
    Search.tileLocs(curvy, ptPairs, iview, genTile);  
       // either search works about the same

    Pics.save(iview.getImage(), "SavedPics/curvey.png");
  } // end of main()


} // end of DrawCurves class
