
// DrawHexs.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Use of composition to create a hexagon tile from
   six triangle tiles.

   This triangle image is also used in DrawTris.java and Triangles.java
*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;


public class DrawHexs
{
  private static final int TILE_WIDTH = 300;     
  private static final int TILE_HEIGHT = 300;


  public static void main(String args[])
  {
    Tile hexTile = makeHexTile();

    ImageViewer iview = Pics.view("Hexagons",  Pics.altScreen());
    BufferedImage scrIm = iview.getImage();

    // calculate offsets for drawing each hexTile
    int horizDist = (int)hexTile.getPolar("H1").getRadius();
    System.out.println("\nHoriz Dist: " + horizDist);

    int vertDist = (int)Math.abs(hexTile.getCartesian("H0").y);
    System.out.println("Vert Dist: " + vertDist);
    
    // display tiles (simplified by allowing over-writing)
    for (int x = 0; x < scrIm.getWidth(); x = x + horizDist) {
      for (int y=0; y < scrIm.getHeight(); y = y + vertDist*2)
        hexTile.draw(scrIm, x, y);   // draw centered at (x,y)
      iview.repaint();
      Pics.pause(100);
    }

    Pics.save(scrIm, "SavedPics/hexs.png");
  } // end of main()



  private static Tile makeHexTile()
  {
    Tile tri = new Tile("data/trif.png");
    tri.addPt("A", 51,6);
    tri.addPt("B", 4,86);
    tri.addPt("C", 97,86);

    tri.view();
    tri.reportPoints();


    BufferedImage hexIm = new BufferedImage(TILE_WIDTH, TILE_HEIGHT, 
                    BufferedImage.TYPE_INT_ARGB);  // alpha channel

    /* The hexagon is six triangles drawn around the center; 
       the corner points of the hexagon are also collected */
    Point2D.Double[] corners = new Point2D.Double[6];
    for (int i=0; i < 6; i++) {
      Tile t = tri.rotate(i*60);
      t.drawAt(hexIm, "A", TILE_WIDTH/2, TILE_HEIGHT/2);
      corners[i] = t.getPtLoc("C");  // right bottom corner of current triangle
    }

    // build hexagon tile, and add its corners
    Tile hexTile = new Tile(hexIm, "hex");
    for (int i=0; i < corners.length; i++)
      hexTile.addPt("H"+i, corners[i]);

    hexTile.view();
    hexTile.reportPoints();

    return hexTile;
  }   // end of makeHexTile()


} // end of DrawHexs class
