
// DrawHorses.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Use of recursion to create an Escher-style drawing.
 
   Based on the horse tesselation explained in the slides
   "Square Limit by M.C. Escher" at 
   https://slideplayer.com/slide/9037436/, published by
   Piers Chandler.
*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;


public class DrawHorses
{
  // size of the drawing surface
  private static final int PWIDTH = 800;     
  private static final int PHEIGHT = 800;

  private static final Color LIGHT_BLUE = new Color(173,216,230);
  private static final Color GRAY_GREEN = new Color(179, 204, 204);
  private static final Color LIGHT_BROWN = new Color(214, 214, 194);


  public static void main(String args[])
  {
    // create two 'horse' tiles
    Tile horse = new Tile("data/horse.png");
    horse.addPt("C0", 165,30);  
    horse.addPt("C1", 90,210);
    horse.addPt("C2", 129,300);
    horse.addPt("C3", 165,210);
    horse.addPt("C4", 201,300);
    horse.addPt("C5", 240,210);

    horse.view();
    horse.reportPoints();

    Tile darkHorse = horse.colorChg(Color.WHITE, LIGHT_BROWN);


    ImageViewer iview = Pics.view("Horses", PWIDTH, PHEIGHT);

    // color the background
    Graphics2D g2d = Pics.createGraphics(iview.getImage());
    g2d.setColor(LIGHT_BLUE);
    g2d.fillRect(0, 0, PWIDTH, PHEIGHT);

    Point2D.Double startPt = new Point2D.Double(PWIDTH/2, PHEIGHT/2);
                                      // center of screen

    // draw eight times around the start point
    for (int i=0; i < 8; i++) {
      Tile h0 = horse.rotate(45*i);
      Tile h1 = darkHorse.rotate(45*i);
      if (i%2 == 0)  // swap horses based on i
        drawLevel(1, 4, h0, h1, startPt, iview);   // four levels deep
      else
        drawLevel(1, 4, h1, h0, startPt, iview);
      Pics.pause(50);
    }

    Pics.save(iview.getImage(), "SavedPics/escherHorses.png");
  } // end of main()



  private static void drawLevel(int n, int max, Tile h0, Tile h1, 
                        Point2D.Double topPt, ImageViewer iview)
  {
    if (n > max)
      return;

    Tile t = (n%2 != 0) ? h0 : h1;
    t.drawAt(iview.getImage(), "C0", topPt);

    Tile smallH0 = h0.resize(0.5);
    Tile smallH1 = h1.resize(0.5);
    drawLevel(n+1, max, smallH0, smallH1, t.getPtLoc("C1"), iview);
    drawLevel(n+1, max, smallH0, smallH1, t.getPtLoc("C3"), iview);
    drawLevel(n+1, max, smallH0, smallH1, t.getPtLoc("C5"), iview);

    iview.repaint();
  } // end of drawScene()


} // end of DrawHorses class
