
// DrawLizards.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Draw a series of Escher-style lizards

   Illustrates the addition of inner points, automatic outers, and a 
   tile generation function, necessary for using built-in search.
*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;
import java.util.function.*;



public class DrawLizards 
{

  private static final Color[] colors = { 
       new Color(199,255,244), new Color(255, 210, 199),
       new Color(255, 238, 119), new Color(221, 199, 255)
  };   // https://www.sessions.edu/color-calculator/

  private static Random rand = new Random();

  private static Tile lizard;  // global so can be used in genTile()



  public static void main(String args[])
  {
    lizard = new Tile("data/liz.png");
    lizard.addPt("C0", 113, 43);    // obtained by calling ViewTile.java
    lizard.addPt("C1", 57, 80);     // then using MS paint to examine TileViewer.png
    lizard.addPt("C2", 61, 147);
    lizard.addPt("C3", 126, 186);   // defines a hexagon
    lizard.addPt("C4", 193, 148);
    lizard.addPt("C5", 184, 73);

    double[] xs = new double[] {    // obtained using Spotty.java
         57,  86,  91,  82,  70, 103,  85,  94,
        112, 116, 138, 149, 172, 182, 197, 179,
        154, 156, 126, 126, 141, 111 };
    double[] ys = new double[] {
         66,  58,  88, 112, 132, 155, 137, 197,
        181, 123, 123, 158, 151, 115, 103,  84,
         89, 105,  86,  49,  29, 103 };
    lizard.addInners(xs, ys); 

    // outers are automatically generated, and okay according to Tile.view()
    lizard.view();
    lizard.reportPoints();

    PointPairs ptPairs = new PointPairs();
    ptPairs.add("C0", "C2");  // lizard pts
    ptPairs.add("C1", "C1");
    ptPairs.add("C2", "C4");
    ptPairs.add("C3", "C3");
    ptPairs.add("C4", "C0");
    ptPairs.add("C5", "C5");
    ptPairs.print();

			 
    Function<String, Tile> genTile = 
        (String nm)->{return lizard.colorChg(Color.WHITE, 
                               colors[rand.nextInt(colors.length)]); };

    // draw tiles on the screen
    ImageViewer iview = Pics.view("Lizards", Pics.altScreen());
    Search.tileLocs(lizard, ptPairs, iview, genTile);
    Pics.save(iview.getImage(), "SavedPics/lizards.png");

  } // end of main()


} // end of DrawLizards class
