
// DrawQuarters.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* A tile using an image file with a large amount of transparent pixels
   and default inner/outer points that don't match the image.
 
   tileSpacey() still works but tileLocs() gives poor results.
*/

import java.awt.*;
import java.awt.image.*;
import java.util.*;
import java.util.function.*;
import java.awt.geom.*;



public class DrawQuarters
{
  private static Tile quart;


  public static void main(String args[])
  {
    quart = new Tile("data/quarter.png");
    // define four points so shape is treated like a square
    quart.addPt("A0", 19, 18);
    quart.addPt("A1", 19, 100);  // obtained by viewing the image in MS paint
    quart.addPt("A2", 101, 100);  
    quart.addPt("A3", 101, 18);  // no image under this point which causes problems
                                 // if using tileLocs()
    quart.view();
    quart.reportPoints();

    PointPairs ptPairs = new PointPairs(quart);  // all points can match
    ptPairs.print();

    Function<String, Tile> genTile = 
                      (String nm)->{return quart.clone();};

    // draw tiles on the screen
    ImageViewer iview = Pics.view("Draw Quarters", Pics.altScreen());

    Search.tileSpacey(quart, ptPairs, iview, genTile);
    // Search.tileLocs(quart, ptPairs, iview, genTile);  
        /* tileLocs() is slow and makes poor choices due to 
           the transparent sides of the tile */

    Pics.save(iview.getImage(), "SavedPics/quarters.png");
  } // end of main()


} // end of DrawQuarters class
