
// DrawShapes.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Four polygons are defined: sq (square), equ (equilateral triangle),
   hex (a hexagon), and octo (an octagon).

   Uses various ways to decorate the tile surface.

   Uses different point pairings to affect how the tiling is
   carried out by tileSpacey() or tileLocs()
*/

import java.awt.*;
import java.awt.image.*;
import java.util.*;
import java.util.function.*;
import java.awt.geom.*;



public class DrawShapes
{
  private static final Color LIGHT_BLUE = new Color(173,216,230);

  private static Tile sq, equ, hex, octo;


  public static void main(String args[])
  {
    // ----- define the tiles ------

    sq = new Tile("data/sqTile.txt");  
         // a square; points start with 'S'
    Graphics2D g2d = sq.getGraphics();
    // red circle
    g2d.setColor(Color.RED);
    g2d.fillOval(40, 25, 10, 10);  // near top 
    sq.view();
    sq.reportPoints();


    equ = new Tile("data/equTile.txt");  
          // equilateral triangle; points start with 'E'
    g2d = equ.getGraphics();
    // contains a small blue square
    g2d.setColor(Color.BLUE);
    g2d.fill( ShapeOps.nPolygon(50, 35, 8, 4));  
              // constrained using a small shape
    equ.view();
    equ.reportPoints();


    Shape s = ShapeOps.nPolygon(60, 60, 50, 6);  
                            // center, side len, no. sides
    hex = new Tile(s, "hexagon").colorChg(Color.WHITE, LIGHT_BLUE);
              // a hexagon; points start with 'H'
    hex.view();
    hex.reportPoints();


    s = ShapeOps.nPolygon(100, 100, 50, 8);  
    octo = new Tile(s, "octagon");
            // an octagon; points start with 'O'
    g2d = octo.getGraphics();
    g2d.setPaint( Pics.loadTex("data/fabric.jpg"));
    g2d.fill(s);    // the entire shape is filled with the texture paint
    octo.view();
    octo.reportPoints();


    // ------------------
    // 3 different pairings to force different tilings to be drawn
    

    // PointPairs ptPairs = new PointPairs( new Tile[]{octo, sq });  
    PointPairs ptPairs = new PointPairs( new Tile[]{sq, equ });  
                                     //{ sq, equ, hex, octo});
         // 1) all points of all the named tiles can pair together
         // some mix of shapes generate spaces, so tileSpacey() should be used


/*
    PointPairs ptPairs = new PointPairs();
    ptPairs.add(octo.getPtNames(), sq.getPtNames());
    ptPairs.add(sq.getPtNames(), octo.getPtNames());
           // 2) each shape can only pair with the other shape type;
           //    generates diamond spaces, so tileSpacey() should be used
*/

/*
    PointPairs ptPairs = new PointPairs();
    ptPairs.add(sq.getPtNames(), equ.getPtNames());
    ptPairs.add(equ.getPtNames(), sq.getPtNames());
           // 3) each shape can only pair with the other shape type;
           //    generates triangle spaces, so tileSpacey() should be used
*/
    ptPairs.print();


    // ------------------
    // draw tiles on the screen

    ImageViewer iview = Pics.view("Draw Shapes", Pics.altScreen());

    // Search.tileSpacey(octo, ptPairs, iview, DrawShapes::genTile);  // starting tile
    // Search.tileSpacey(sq, ptPairs, iview, DrawShapes::genTile);    // can vary

    Search.tileLocs(sq, ptPairs, iview, DrawShapes::genTile); 
         // tileLocs() tries to avoid spaces

    Pics.save(iview.getImage(), "SavedPics/shapes.png");

  } // end of main()



  private static Tile genTile(String ptName)
  // point names begin with 'S', 'E', 'H', or 'O'
  {
    char ch = ptName.charAt(0);
    switch(ch) {
      case 'S': return sq.clone();
      case 'E': return equ.clone();
      case 'H': return hex.clone();
      case 'O': return octo.clone();
      default: System.out.println("Unknown point name: " + ptName);
    }
    return null;
  }  // end of genTile()


} // end of DrawShapes class
