
// DrawTris.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Draw triangle tiles row-by-row. See Triangles.java for how 
   built-in tileLocs() search is used with this tile.

   The same image is used in DrawHexs.java to draw hexagons.
*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;


public class DrawTris
{

  public static void main(String args[])
  {
    // two tiles are generated before tiling begins

    Tile t = new Tile("data/trif.png");
    t.addPt("T0", 51,6);   // added in ccw order
    t.addPt("T1", 4,86);   // coords obtained by viewing the image in MS Paint
    t.addPt("T2", 97,86);
    t.view();
    t.reportPoints();

    Tile rot = t.rotate(180);
    rot.setID("rot");    // this does not change the point names
    rot.view();
    rot.reportPoints();

    ImageViewer iview = Pics.view("Triangles row-by-row", Pics.altScreen());
    BufferedImage scrIm = iview.getImage();
    int pWidth = scrIm.getWidth();
    int pHeight = scrIm.getHeight();

    // display tiles row-by-row
    int rowNum = 1;
    Point2D.Double startPt = new Point2D.Double(30,0);
    Point2D.Double nextPt;

    while (startPt.y < pHeight) {
      // start of a row
      if (rowNum%2 == 1) {  // odd row; t then rot
        t.drawAt(scrIm, "T0", startPt);
        rot.drawAt(scrIm, "T2", startPt);
        startPt = t.getPtLoc("T1");
        nextPt = rot.getPtLoc("T1");
      }
      else {  // even row; rot then t
        rot.drawAt(scrIm, "T2", startPt);
        t.drawAt(scrIm, "T0", rot.getPtLoc("T1"));
        startPt = rot.getPtLoc("T0");
        nextPt = t.getPtLoc("T0");
      }

      // rest of row  
      while (nextPt.x < pWidth) {
        if (rowNum%2 == 1) {  // odd row; t then rot
          t.drawAt(scrIm, "T0", nextPt);
          rot.drawAt(scrIm, "T2", nextPt);
          nextPt = rot.getPtLoc("T1");
        }
        else {   // even row; rot then t
          rot.drawAt(scrIm, "T2", nextPt);
          t.drawAt(scrIm, "T0", rot.getPtLoc("T1"));
          nextPt = t.getPtLoc("T0");
        }
        iview.repaint();
      }
      Pics.pause(100);   // delay after each row is drawn
      rowNum++;
    }

    Pics.save(scrIm, "SavedPics/trianglesRow.png");
  } // end of main()


} // end of DrawTris class
