
// ImPentagons.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Draw pentagon tiles based on an image. The tiling will include
   spaces, and tileLocs() only magaes to draw one tile. However,
   tileSpacey() does a better job.

   See Pentagons.java for a more accurate shape-based tile.
*/

import java.awt.*;
import java.awt.image.*;
import java.util.*;
import java.util.function.*;
import java.awt.geom.*;



public class ImPentagons
{
  private static Tile penta;


  public static void main(String args[])
  {
    penta = new Tile("data/pentagon.png");
    penta.addPt("P0", 87,23);   // added in ccw order
    penta.addPt("P1", 36,58);   // coords obtained from looking at Tile.view()
    penta.addPt("P2", 56,118);
    penta.addPt("P3", 118,118);
    penta.addPt("P4", 137,58);

    // create my own inner and outer points

    double[] dxs = { 87, 70, 53, 60, 65, 87,110,116,121,103 };  // obtained with Spotty
    double[] dys = { 37, 50, 63, 84,105,105,105, 83, 64, 48 };
    penta.addInners(dxs, dys);

    penta.addOuter("P0", "P1", 53, 36);   // obtained with Spotty
    penta.addOuter("P1", "P2", 36, 93);
    penta.addOuter("P2", "P3", 85,128);
    penta.addOuter("P3", "P4", 136, 96);
    penta.addOuter("P4", "P0", 116, 32);

    penta.view();
    penta.reportPoints();

    // same code used in Pentagons.java: 

    PointPairs ptPairs = new PointPairs(penta);

    Function<String, Tile> genTile = 
                      (String nm)->{return penta.clone();};

    // draw tiles on the screen
    ImageViewer iview = Pics.view("Image Pentagons", Pics.altScreen());
    Search.tileSpacey(penta, ptPairs, iview, genTile);
    // Search.tileLocs(penta, ptPairs, iview, genTile);    // only one tile drawn

    Pics.save(iview.getImage(), "SavedPics/pentasIm.png");
  } // end of main()



} // end of ImPentagons class
