
// Isoceles.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Tile with an isoceles triangle.
   The point pairs are a little more complex since the sides are
   not all equal.

   tileLocs() leaves quite a lot of spaces. Often tileSpacey()
   gives (slightly) better results.

   This illustrates the need for a backtracking search function.
   Also, see DrawPenrose.java.
*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;
import java.util.function.*;



public class Isoceles
{

  private static Tile tri;   // so can be used in genTile()


  public static void main(String args[])
  {
    // A isoceles triangle with a red dot below the tip
    tri = new Tile("data/isoTile.txt");
    Graphics2D g2d = tri.getGraphics();
    g2d.setColor(Color.RED);
    g2d.fillOval(48,40, 6, 6);  // coord obtained by using ViewTile

    // using Spotty
    double[] xs = new double[] {
         50,  49,  45,  53,  40,  49,  59,  38,
         51,  59,  35,  50,  61 };
    double[] ys = new double[] {
         36,  47,  64,  63,  80,  80,  80,  93,
         93,  93, 105, 103, 103 };
    tri.addInners(xs, ys);

    tri.addOuter("I0", "I1", 29, 63);  // using Spotty
    tri.addOuter("I1", "I2", 48, 122);
    tri.addOuter("I2", "I0", 72, 67);

    tri.view();
    tri.reportPoints();

    PointPairs ptPairs = PointPairs.matchLens(tri);
    ptPairs.print();

    Function<String, Tile> genTile = 
                      (String nm)->{return tri.clone();};

    // draw tiles on the screen
    ImageViewer iview = Pics.view("Isoceles", Pics.altScreen());

    // Search.tileLocs(tri, ptPairs, iview, genTile, 700);
    Search.tileSpacey(tri, ptPairs, iview, genTile, 700);

    Pics.save(iview.getImage(), "SavedPics/isoceles.png");

  } // end of main()



} // end of Isoceles class
