
// Pentagons.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Draw pentagon tiles based on a shape. The tiling will include
   spaces, and tileLocs() runs quite slowly; tileSpacey() is faster.

   See imPentagons.java for a less accurate image-based tile.
*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;
import java.util.function.*;



public class Pentagons
{

  private static Tile penta;


  public static void main(String args[])
  {
    penta = buildPentagon();

    // use automatically generated inner and outer points

    // same code used in ImPentagons.java: 

    PointPairs ptPairs = new PointPairs(penta);

    Function<String, Tile> genTile = 
                      (String nm)->{return penta.clone();};

    // draw tiles on the screen
    ImageViewer iview = Pics.view("Shape Pentagons", Pics.altScreen());

    // Search.tileLocs(penta, ptPairs, iview, genTile);    // slower, but works
    Search.tileSpacey(penta, ptPairs, iview, genTile, 900);  // increased tile max

    Pics.save(iview.getImage(), "SavedPics/pentas.png");
  } // end of main()




  private static Tile buildPentagon()
  // A pentagon containing a red dot and blue triangle
  {
    Shape s = ShapeOps.nPolygon(Tile.WIDTH/2, Tile.HEIGHT/2, 30, 5);
                            // center, length, no. sides
    s = ShapeOps.rotate(s, 90);   // rotate first point to top
    Tile t = new Tile(s, "pentagon");
    Graphics2D g2d = t.getGraphics();

    ArrayList<Point2D.Double> pts = t.getImPts();

    // red circle
    g2d.setColor(Color.RED);
    g2d.fillOval((int)pts.get(0).x-5, (int)pts.get(0).y+10, 10, 10);
                // below top point of pentagon

    // blue triangle
    Shape tri = ShapeOps.radPolygon(50, 64, 7, 3);   
                  // coordinates obtained from looking at Tile.view()
    tri = ShapeOps.rotate(tri, 90);  // so tip points upwards
    g2d.setColor(Color.BLUE);
    g2d.fill(tri);

    t.view();
    t.reportPoints();

    return t;
  }  // end of drawPentagon()


} // end of Pentagons class
