
// Spirals.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Spiral Tiling using Penrose's Kite (P2)
   e.g. see https://en.wikipedia.org/wiki/Penrose_tiling
            https://mathworld.wolfram.com/PenroseTiles.html

   Also see DrawPenrose, PenroseClusters.java

*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;



public class Spirals
{
  private static final int NUM_PATHS = 5;
  private static final int NUM_KITES = 8;
  private static final double PHI = (1.0 + Math.sqrt(5))/2.0;

  private static Tile kite;


  public static void main(String args[])
  {
    // colors used along each spiral path
    Color[] palette = new Color[NUM_PATHS];  // https://coolors.co/
    palette[0] = new Color(138, 163, 153);
    palette[1] = new Color(125, 132, 178);
    palette[2] = new Color(143, 166, 203);
    palette[3] = new Color(219, 244, 167);
    palette[4] = new Color(213, 249, 222);

    kite = new Tile("data/kiteTile.txt").rotate(-18);
    kite.view();
    kite.reportPoints();

    Tile[] sizedKites = new Tile[NUM_KITES];
    sizedKites[3] = kite;

    double scale = PHI;     // 3 are smaller
    for (int i=2; i >= 0; i--) {
      sizedKites[i] = sizedKites[3].resize(1.0/scale);
      scale *= PHI;
    }
    scale = PHI;   // 4 are bigger
    for (int i = 4; i < NUM_KITES; i++) {
      sizedKites[i] = sizedKites[3].resize(scale);
      scale *= PHI;
    }

    // draw tiles on the screen
    ImageViewer iview =  Pics.view("Spirals", Pics.altScreen());  
    BufferedImage im = iview.getImage(); 
    int w = im.getWidth();
    int h = im.getHeight();

    // generate pentagon offsets from center
    Shape penta = ShapeOps.nPolygon(w/2, h/2, 14.59, NUM_PATHS);
            // length is 100 * 1/phi^4
    penta = ShapeOps.rotate(penta,90);  // so tip is at top
    ArrayList<Point2D.Double> pts = ShapeOps.getPoints(penta);
    //System.out.println("Pentagon pts: " + 
    //                      Arrays.toString(pts.toArray()));

    for(int j=0; j < NUM_PATHS; j++) {
      double angle = 72*j;
      Tile k = sizedKites[0].rotate(angle).colorChg(palette[j]);
      k.drawAt(im, "K1", pts.get(j));
    
      Tile rotKite;
      for(int i=1; i < NUM_KITES; i++) {
        double rotAngle = sizedKites[i].edgeRotation("K1", k, "K2");
        rotKite = sizedKites[i].rotate(rotAngle).
                                colorChg(palette[j]);
        rotKite.drawAt(im, "K1", k.getPtLoc("K2"));
        iview.repaint();
        k = rotKite;
      }
    }

    Pics.save(iview.getImage(), "SavedPics/spirals.png");
  } // end of main()



} // end of Spirals class
