
// Stars.java
// Andrew Davison, May 2022, ad@fivedots.coe.psu.ac.th

/* Illustrates the composition of tiles (a star + two 'y' tiles).
   The new tile is used to tile the screen.
*/

import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import java.util.*;



public class Stars
{

  public static void main(String args[])
  {
    // load the star tile
    Tile starTile = new Tile("data/starTile.txt");  // its points start with 'S'
    Graphics2D g2d = starTile.getGraphics();
    g2d.setPaint(Pics.loadTex("data/fabric.jpg"));
    g2d.fill( starTile.getShape());    // painting is constrained within the shape
    starTile.view();
    starTile.reportPoints();

    // load the 'Y' tile
    Tile yTile = new Tile("data/yTile.txt"); // its points start with 'Y'
    g2d = yTile.getGraphics();
    g2d.setClip(yTile.getShape());
    g2d.setColor(Color.RED);
    g2d.setStroke(new BasicStroke(2.0f));
    g2d.drawLine(15, 0, yTile.getWidth(),   // only visible inside shape due to the clip
                        yTile.getHeight()-5);
    yTile.view();
    yTile.reportPoints();

    // create a new tile composed from one star and two 'Y' tiles
    Tile starYY = makeStarYY(starTile, yTile);
    starYY.view();
    starYY.reportPoints();

    // tile the screen with the new tile
    place(starYY);
  } // end of main()



  private static Tile makeStarYY(Tile starTile, Tile yTile)
  // generate a tile built from a star and two 'y' tiles
  {
    BufferedImage im = new BufferedImage(200, 200, 
                     BufferedImage.TYPE_INT_ARGB);  // alpha channel

    starTile.drawAt(im, "S0", 30,40);
    Point2D.Double centerPt = starTile.getPtLoc("S6");

    yTile.drawAt(im, "Y3", centerPt);

    Tile yTileRot = yTile.rotate(-60);
    yTileRot.drawAt(im, "Y7", centerPt);

    Point2D.Double[] corners = new Point2D.Double[5];
    corners[0] = starTile.getPtLoc("S2");
    corners[1] = starTile.getPtLoc("S10");
    corners[2] = yTile.getPtLoc("Y0");
    corners[3] = yTileRot.getPtLoc("Y4");
    corners[4] = yTileRot.getPtLoc("Y1");

    // build tile using image and corner points
    Tile starYY = new Tile(im, "starYY");
    for (int i=0; i < corners.length; i++)
      starYY.addPt("C"+i, corners[i]);  
      // the new tile uses points that start with 'C'

    return starYY;
  }   // end of makeStarYY()



  private static void place(Tile starYY)
  { 
    ImageViewer iview = Pics.view("Stars and Ys", Pics.altScreen());
    BufferedImage scrImage = iview.getImage();
    int pWidth = scrImage.getWidth();
    int pHeight = scrImage.getHeight();

    int rowNum = 0;
    Point2D.Double startPt = new Point2D.Double(0,-10);
    Point2D.Double nextPt;

    while (startPt.y < pHeight) {
      starYY.drawAt(scrImage, "C0", startPt);
      iview.repaint();

      if (rowNum%2 == 0)   // rowNum is even
        startPt = starYY.getPtLoc("C2");
      else  // odd
        startPt = starYY.getPtLoc("C3");

      nextPt = starYY.getPtLoc("C4");
      while (nextPt.x < pWidth) {
        starYY.drawAt(scrImage, "C1", nextPt);
        nextPt = starYY.getPtLoc("C4");
        iview.repaint();
      }
      Pics.pause(100);
      rowNum++;
    }

    Pics.save(scrImage, "SavedPics/stars.png");
  }  // end of place()


} // end of Stars class
